@@ -466,7 +466,8 @@ class TaskBarIcon(wx.adv.TaskBarIcon):
 
     def show_log(self, event):
         content = ''
-        file_path = os.path.join(user_home, 'ucnp_client', 'log', 'up_utils.log')
+        file_path = os.path.join(user_home, 'ucnp_client', 'log',
+                                 'up_utils.log')
         if os.path.isfile(file_path):
             with open(file_path, 'r') as f:
                 content = f.read()
